@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2019 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -202,7 +202,8 @@ class CWidgetHelper {
 					'srcfld1' => 'groupid',
 					'dstfrm' => $form_name,
 					'dstfld1' => zbx_formatDomId($field_name),
-					'real_hosts' => true
+					'real_hosts' => true,
+					'enrich_parent_groups' => true
 				]
 			],
 			'add_post_js' => false
@@ -539,6 +540,7 @@ class CWidgetHelper {
 									'multiselect' => 1,
 									'real_hosts' => 1,
 									'numeric' => 1,
+									'with_webitems' => 1,
 									'orig_names' => 1,
 									'dstfrm' => $form_name
 								]).', {dstfld1: jQuery(this).siblings("textarea").attr("name")}), null, this);'
@@ -881,7 +883,7 @@ class CWidgetHelper {
 									'reference' => 'name',
 									'multiselect' => 1,
 									'dstfrm' => $form_name
-								]) . ', {dstfld1: jQuery(this).siblings("textarea").attr("name")}), null, this);'
+								]).', {dstfld1: jQuery(this).siblings("textarea").attr("name")}), null, this);'
 							)
 					]))->addClass(ZBX_STYLE_COLUMN_50),
 					(new CDiv([
@@ -897,7 +899,6 @@ class CWidgetHelper {
 								CJs::encodeJson([
 									'srctbl' => 'items',
 									'srcfld1' => 'itemid',
-									'srcfld2' => 'name',
 									'reference' => 'name_expanded',
 									'multiselect' => 1,
 									'real_hosts' => 1,
@@ -905,7 +906,7 @@ class CWidgetHelper {
 									'with_webitems' => 1,
 									'orig_names' => 1,
 									'dstfrm' => $form_name
-								]) . ', {dstfld1: jQuery(this).siblings("textarea").attr("name")}), null, this);'
+								]).', {dstfld1: jQuery(this).siblings("textarea").attr("name")}), null, this);'
 							)
 					]))->addClass(ZBX_STYLE_COLUMN_50),
 				]))
@@ -915,8 +916,7 @@ class CWidgetHelper {
 					(new CButton())
 						->setAttribute('title', _('Delete'))
 						->addClass(ZBX_STYLE_REMOVE_BTN)
-				]))
-					->addClass(ZBX_STYLE_COLUMN_5)
+				]))->addClass(ZBX_STYLE_COLUMN_5)
 			]))
 				->addClass(ZBX_STYLE_LIST_ACCORDION_ITEM_HEAD)
 				->addClass(ZBX_STYLE_COLUMNS),
@@ -1231,6 +1231,7 @@ class CWidgetHelper {
 	 * @return string
 	 */
 	public static function makeStringFromChunks(array $chunks) {
+		ksort($chunks);
 		return implode('', $chunks);
 	}
 
@@ -1242,7 +1243,7 @@ class CWidgetHelper {
 	 * @return array  Returns array of unique patterns.
 	 */
 	public static function splitPatternIntoParts($patterns) {
-		$patterns = is_array($patterns) ? $patterns : str_split(str_replace("\r", '', $patterns), 255);
+		$patterns = is_array($patterns) ? $patterns : str_split(str_replace("\r", '', trim($patterns)), 255);
 		return array_filter($patterns, 'strlen');
 	}
 }
